import { useState } from 'react';
import { getGzhPlanListApi } from '@src/http/api';
import request from '@src/http/index';
import { VideoItem } from '../components/types';

export interface GzhPlanType {
  accountId: number;
  accountName: string;
  createTimestamp: number;
  id: number;
  publishStage: number;
  scene: number;
  title: string[];
	videoCount: number;
	videoList: VideoItem[];
}

interface GzhPlanListParams {
	accountId?: number;
	createTimestampEnd?: number;
	createTimestampStart?: number;
	publishStage?: number;
	title?: string;
	pageNum: number;
	pageSize: number;
}

interface GzhPlanListResponse {
	objs: GzhPlanType[];
	totalSize: number;
}

export const useGzhPlanList = () => {
  const [gzhPlanList, setGzhPlanList] = useState<GzhPlanType[]>([]);
  const [loading, setLoading] = useState(false);
	const [error, setError] = useState<string | null>(null);
	const [totalSize, setTotalSize] = useState(0);

	const getGzhPlanList = async ({
		accountId,
		createTimestampEnd,
		createTimestampStart,
		publishStage,
		title,
		pageNum,
		pageSize
	}: GzhPlanListParams) => {
    try {
      setLoading(true);
      setError(null);
			const data = await request.post<GzhPlanListResponse>(getGzhPlanListApi, {
				accountId: accountId,
				createTimestampEnd,
				createTimestampStart,
				publishStage,
				title,
				pageNum,
				pageSize,
			});
      setGzhPlanList(data.data.objs as GzhPlanType[]);
			setTotalSize(data.data.totalSize);
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to fetch accounts');
    } finally {
      setLoading(false);
    }
  };

  return {
    gzhPlanList,
		getGzhPlanList,
		totalSize,
    loading,
    error
  };
}; 
